@@ -4,17 +4,17 @@
 #
 # Logic of the `mc search` action.
 #
-import csv
+import casanova
 
-from minet.cli.utils import LoadingBar
+from minet.cli.loading_bar import LoadingBar
+from minet.cli.mediacloud.utils import with_mediacloud_fatal_errors
 from minet.mediacloud import MediacloudAPIClient
-from minet.mediacloud.constants import MEDIACLOUD_STORIES_CSV_HEADER
-from minet.mediacloud.exceptions import MediacloudServerError
+from minet.mediacloud.types import MediacloudStory
 
 
-def mediacloud_search_action(cli_args):
-    writer = csv.writer(cli_args.output)
-    writer.writerow(MEDIACLOUD_STORIES_CSV_HEADER)
+@with_mediacloud_fatal_errors
+def action(cli_args):
+    writer = casanova.writer(cli_args.output, fieldnames=MediacloudStory)
 
     client = MediacloudAPIClient(cli_args.token)
 
@@ -27,19 +27,13 @@ def mediacloud_search_action(cli_args):
         "filter_query": cli_args.filter_query,
     }
 
-    loading_bar = LoadingBar("Searching stories", unit="story", unit_plural="stories")
-
-    try:
+    with LoadingBar(title="Searching", unit="stories") as loading_bar:
         if not cli_args.skip_count:
             count = client.count(cli_args.query, **kwargs)
-
-            loading_bar.update_total(count)
+            loading_bar.set_total(count)
 
         iterator = client.search(cli_args.query, **kwargs)
 
         for story in iterator:
             writer.writerow(story.as_csv_row())
-            loading_bar.update()
-
-    except MediacloudServerError as e:
-        loading_bar.die(["Aborted due to a mediacloud server error:", e.server_error])
+            loading_bar.advance()
