@@ -4,16 +4,15 @@
 #
 # Function related to topics.
 #
-from minet.web import request_json
+from minet.web import request
 from minet.mediacloud.constants import MEDIACLOUD_API_BASE_URL, MEDIACLOUD_DEFAULT_BATCH
 from minet.mediacloud.utils import get_next_link_id
-from minet.mediacloud.formatters import format_topic_story
+from minet.mediacloud.types import MediacloudTopicStory
 
 
 def url_forge(
     token=None, topic_id=None, link_id=None, media_id=None, from_media_id=None
 ):
-
     url = "%s/topics/%s/stories/list?key=%s&limit=%i" % (
         MEDIACLOUD_API_BASE_URL,
         topic_id,
@@ -34,9 +33,14 @@ def url_forge(
 
 
 def mediacloud_topic_stories(
-    pool, token, topic_id, link_id=None, media_id=None, from_media_id=None, raw=False
+    pool_manager,
+    token,
+    topic_id,
+    link_id=None,
+    media_id=None,
+    from_media_id=None,
+    raw=False,
 ):
-
     while True:
         url = url_forge(
             token,
@@ -46,10 +50,8 @@ def mediacloud_topic_stories(
             from_media_id=from_media_id,
         )
 
-        err, _, data = request_json(url, pool=pool)
-
-        if err:
-            raise err
+        response = request(url, pool_manager=pool_manager)
+        data = response.json()
 
         if "stories" not in data or len(data["stories"]) == 0:
             return
@@ -58,7 +60,7 @@ def mediacloud_topic_stories(
 
         for story in data["stories"]:
             if not raw:
-                story = format_topic_story(story, next_link_id)
+                story = MediacloudTopicStory.from_payload(story, next_link_id)
 
             yield story
 
