@@ -4,6 +4,8 @@
 #
 # Functions performing analysis of scraper definitions.
 #
+from typing import Optional, List, Literal
+
 import ast
 import soupsieve
 from soupsieve import SelectorSyntaxError
@@ -27,12 +29,23 @@ from minet.scrape.exceptions import (
     ScraperValidationUnknownKeyError,
 )
 
+ScraperAnalysisOutputType = Literal["scalar", "unknown", "collection", "dict", "list"]
+
 
 class ScraperAnalysis(object):
-    __slots__ = ("headers", "plural", "output_type")
+    fieldnames: Optional[List[str]]
+    plural: bool
+    output_type: ScraperAnalysisOutputType
 
-    def __init__(self, headers=None, plural=False, output_type="scalar"):
-        self.headers = headers
+    __slots__ = ("fieldnames", "plural", "output_type")
+
+    def __init__(
+        self,
+        fieldnames: Optional[List[str]] = None,
+        plural: bool = False,
+        output_type: ScraperAnalysisOutputType = "scalar",
+    ):
+        self.fieldnames = fieldnames
         self.plural = plural
         self.output_type = output_type
 
@@ -40,19 +53,22 @@ class ScraperAnalysis(object):
         return (
             self.plural == other.plural
             and self.output_type == other.output_type
-            and set(self.headers) == set(other.headers)
+            and (
+                (self.fieldnames is None and other.fieldnames is None)
+                or (set(self.fieldnames) == set(other.fieldnames))
+            )
         )
 
     def __repr__(self):
-        return "<{name} headers={headers!r} plural={plural} output_type={output_type}>".format(
+        return "<{name} fieldnames={fieldnames!r} plural={plural} output_type={output_type}>".format(
             name=self.__class__.__name__,
-            headers=self.headers,
+            fieldnames=self.fieldnames,
             plural=self.plural,
             output_type=self.output_type,
         )
 
 
-def headers_from_definition(scraper):
+def fieldnames_from_definition(scraper):
     tabulate = scraper.get("tabulate")
 
     if tabulate is not None:
@@ -76,7 +92,7 @@ def headers_from_definition(scraper):
 def analyse(scraper):
     analysis = ScraperAnalysis()
 
-    analysis.headers = headers_from_definition(scraper)
+    analysis.fieldnames = fieldnames_from_definition(scraper)
 
     iterator = get_iterator(scraper)
 
@@ -113,11 +129,9 @@ def errors_sorting_key(error):
 
 
 def validate(scraper):
-
     errors = []
 
     def recurse(node, path=[]):
-
         # Checking conflicts
         c = []
 
@@ -216,8 +230,7 @@ def validate(scraper):
         in_fields = path and path[-1] == "fields"
 
         for k, v in node.items():
-
-            # Unkown keys
+            # Unknown keys
             if not in_fields and k not in KNOWN_KEYS:
                 errors.append(ScraperValidationUnknownKeyError(path=path, key=k))
                 continue
